@@ -162,7 +162,7 @@ SEXP ps__proc_cpu_times(DWORD pid) {
   REAL(result)[1] =
     (double)(ftKernel.dwHighDateTime * 429.4967296 + ftKernel.dwLowDateTime * 1e-7),
   REAL(result)[2] = REAL(result)[3] = NA_REAL;
-  PROTECT(names = ps__build_string("user", "system", "childen_user",
+  PROTECT(names = ps__build_string("user", "system", "children_user",
 				   "children_system", NULL));
   setAttrib(result, R_NamesSymbol, names);
 
@@ -805,5 +805,8 @@ SEXP ps__init(SEXP psenv, SEXP constenv) {
   /* Socket types */
   defineVar(install("socket_types"), ps__define_socket_types(), constenv);
 
+  /* errno values */
+  defineVar(install("errno"), ps__define_errno(), constenv);
+
   return R_NilValue;
 }
